% GENINP Generates folder structures where variables in a template file
%        are replaced according to the inputfile. 
%   
%  The input file should be a textfile formated as shown between the dashed lines
%  below. There are no limitations to how many variables or cases that can be
%  included.
% 
%  example.inp
% ------------------------------------------------------------------------
%   Cases   Var1  Var2  Var3
%   Case1    -     -     - 
%   Case2    -     -     -
%   Case3    -     -     - 
% ------------------------------------------------------------------------
%  The spots marked with - should be replaced by the variable value corresponding
%  to the relevant case. (Note: Variables should be numbers, and columns should be 
%  separated by tabulators.) Folders will be named after the cases. Variables
%  wich are to be replaced have to have the same name in the input and
%  template file.
%
% Input
%    inpdr  - directory for the inputfile.
%    inp    - name of the input file.
%    temdr  - directory for the template file.
%    tem    - name of the template file.
%
% Output
%    out       - returns true if the process completed.
%    casenames - returns names of cases
%    vars      - returns the variables
% 
% Author: Benjamin I. Brynestad - 08.02.2012
% Modified: rjan Fredriksen - 14.03.2012

function [out casenames vars] = geninp(inpdr,inp,temdr,tem)

out = false;

inpath = [inpdr '\' inp];
tempath = [temdr '\' tem];

if isempty(inpdr)|| isempty(inp) || isempty(temdr)|| isempty(tem)
    return
elseif ~ischar(inpdr)||~ischar(inp)|| ~ischar(temdr)||~ischar(tem)
    return
end

data = importdata(inpath);

vars = data.data;

ncases = size(vars,1);
nvars = length(data.textdata(1,:)) - 1;

casenames = data.textdata(2:ncases+1,1);
varnames  = data.textdata(1,2:nvars+1);

for i = 1:ncases
    % Will not create folders if already present
    if ~isdir([temdr '\' char(casenames(i))])
        
        % Create a folder for the relevant case
        mkdir(temdr,char(casenames(i)));
        
        % Copy the template to the folder
        copyfile(tempath,[temdr '\' char(casenames(i))]);
        
        % Storing current file path
        currpath = [temdr '\' char(casenames(i))];
        
        for j = 1:nvars
            replaceinfile(char(varnames(j)), num2str(vars(i,j)), [currpath '\' tem], '-nobak');
        end
    end
end

out = true;
end