% Script to generate input structure using genimp.m, running analyses with
% FE software Abaqus CAE for all load cases using Python scripts, and
% reading the output files to generate different plots.
%
% ScriptStr  = Name of Python script (no extension) (.py)
% LoopStr    = Name of loop file for load cases (no extension) (.txt)
% OutStr1    = Name of primary output file (no extension) (.rpt)
% OutStr2    = Name of secondary (eigenvalues) output file (no extension) (.rpt)
% RunDir     = Root directory of the analysis
% Aba        = Can be False if Analysis results are already present
% Eig        = True if modal analysis, false of integration analysis
%
% Author: rjan Fredriksen
% Created: 13.02.2012 - Modified: 02.06.2012

function runanalysis(ScriptStr,LoopStr,RunDir,Aba,Eig)

% Includes the WAFO toolbox (requires downloading of WAFO)
% addpath('C:\Users\rjan\Documents\MATLAB\wafo25');
% wafopath('tools',1,1);

%%
NV = 5; % Number of output parameters exported from Abaqus database
PlotVar = 2;
MaxFreq = 20;
Smoothing = 500; % Smoothing parameter for spectral density plot (WAFO)
OutStr1 = 'Output';
OutStr2 = 'Eigenfreq';
TitleStr = ['Dynamic Response from Impact Force. Abaqus analysis: ' ScriptStr '.py'];

%% Generating input files
[Status Cases Data] = geninp(RunDir,[LoopStr '.txt'],RunDir,[ScriptStr '.py']); %#ok<ASGLU>
NC = length(Cases); % Number of load cases

%% Running Abaqus (if Aba = true)
if Aba
    H = waitbar(0,['Running ' ScriptStr '.py in Abaqus CAE (completed 0 of ' num2str(NC) ')...']);
    for i = 1:NC
        runabaqus(ScriptStr,[RunDir '\' char(Cases(i))])
        waitbar(i/NC,H,['Running ' ScriptStr '.py in Abaqus CAE (completed ' num2str(i) ' of ' num2str(NC) ')...'])
    end
    close(H)
end

%% Reading output files and scaling values (max=1)
ScaleStr = [OutStr1 'Scaled']; % Requires scaleoutput.m
% SpectStr = [OutStr1 'Spect']; % Requires WAFO
for i = 1:NC
    eval([OutStr1 '(:,:,i) = readoutput(NV,[RunDir ''\'' char(Cases(i))],OutStr1);']); % Requires scaleoutput.m
    eval([ScaleStr '(:,1,i) = ' OutStr1 '(:,1,i);']); % Requires scaleoutput.m

% Requires WAFO
%    eval(['SpectTemp = dat2spec2(' OutStr1 '(:,[1 PlotVar],i),Smoothing);']);
%    eval([SpectStr '(:,1,i) = SpectTemp.w;']);
%    eval([SpectStr '(:,2,i) = SpectTemp.S;']);
%    eval('MaxVal(i) = max(SpectTemp.S);');
    for j = 2:NV
        eval([ScaleStr '(:,j,i) = scaleoutput(' OutStr1 '(:,:,i),j);']);
    end
end

if ~isdir([RunDir '\Plots'])
    mkdir(RunDir,'Plots')
end

%% Generating plots of output (normal and scaled output)
figure(1)
eval(getplotstring(NC,PlotVar,OutStr1))
eval(getlegendstring(NC,'Pulse duration ',Data(:,3),' s'))
title(TitleStr)
xlabel('Time [s]')
ylabel('Vertical displacement [m]')
print(gcf,'-dpng','-r600',[RunDir '\Plots\' ScriptStr])

figure(2)
eval(getplotstring(NC,PlotVar,ScaleStr))
eval(getlegendstring(NC,'Pulse duration ',Data(:,3),' s'))
title(TitleStr)
xlabel('Time [s]')
ylabel('Vertical displacement / Maximum displacement')
print(gcf,'-dpng','-r600',[RunDir '\Plots\' ScriptStr 'Scaled'])

% Requires WAFO
% figure(3)
% eval(getplotstring(NC,2,SpectStr))
% eval(getlegendstring(NC,'Pulse duration ',Data(:,3),' s'))
% title(TitleStr)
% xlabel('Frequency [rad/s]')
% ylabel('Energy density [m^2*s]')
% axis([0 MaxFreq 0 max(MaxVal)])
% print(gcf,'-dpng','-r600',[RunDir '\Plots\' ScriptStr 'Spectral'])

%% Reading eigenvalue output and calculates eigenperiods (if Eig = true)
if Eig
    eigenplot([RunDir '\' char(Cases(1))],OutStr2,ScriptStr); % Requires eigenplot.m
    print(gcf,'-dpng','-r600',[RunDir '\Plots\' OutStr2])
end

close all
end